# Youtube-Video-Thumbnail

A youtube video link or id to video thumbnail python package.

---

```
Made with Python3
(C) @FayasNoushad
Copyright permission under MIT License
License -> https://github.com/FayasNoushad/Youtube-Video-Thumbnail/blob/main/LICENSE
```

---

## Installation

```
pip3 install ytthumb
```

---

## Usage

### Basic Usage

```python
import ytthumb

ytthumb.thumbnail("https://youtu.be/rokGy0huYEA")
```

### Advanced Usage

```python
import ytthumb

ytthumb.thumbnail("https://youtu.be/rokGy0huYEA", quality="sd")
```

<details>
  <summary><b>Available Qualities</b></summary>
<br/>

- sd - Standard Quality
- mq - Medium Quality
- hq - High Quality
- maxres - Maximum Resolution

</details>

---

## Help

```python
import ytthumb

help(ytthumb.thumbnail)
```

---

## Credits

- [Fayas Noushad](https://github.com/FayasNoushad)
